PlexResource class
One server entry from plex.tv/api/v2/resources.
connections is the list of candidate URIs to reach the server —
pick the best one with bestConnection.
Constructors
-
PlexResource({required String name, required String clientIdentifier, required String product, required String productVersion, required String platform, required bool owned, required bool home, required bool synced, required bool relay, required bool presence, required bool httpsRequired, required String accessToken, required List<
String> provides, required List<PlexServerConnection> connections, String? device, String? publicAddress}) -
const
-
PlexResource.fromJson(Map<
String, dynamic> json) -
factory
Properties
- accessToken → String
-
final
- clientIdentifier → String
-
final
-
connections
→ List<
PlexServerConnection> -
final
- device → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- home → bool
-
final
- httpsRequired → bool
-
final
- isServer → bool
-
Whether this resource is a Plex Media Server (vs. a player/client).
no setter
- name → String
-
final
- owned → bool
-
final
- platform → String
-
final
- presence → bool
-
final
- product → String
-
final
- productVersion → String
-
final
-
provides
→ List<
String> -
final
- publicAddress → String?
-
final
- relay → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- synced → bool
-
final
Methods
-
bestConnection(
) → PlexServerConnection? - Pick the most desirable connection URI in this order:
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited