PlexSessionPlayer class
Constructors
Properties
- address → String?
-
final
- device → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- local → bool
-
final
- platform → String?
-
final
- product → String?
-
final
-
raw
→ Map<
String, dynamic> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → String?
-
final
- title → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited